@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
@@ -5,13 +7,24 @@
 #include "anisotropic.hh"
 #include <dune/common/timer.hh>
 #include <dune/common/parallel/indexset.hh>
-#include <dune/common/parallel/collectivecommunication.hh>
+#include <dune/common/parallel/communication.hh>
 #include <dune/istl/paamg/fastamg.hh>
 #include <dune/istl/paamg/pinfo.hh>
 #include <dune/istl/solvers.hh>
 #include <cstdlib>
 #include <ctime>
 
+namespace Dune
+{
+  using Mat = BCRSMatrix<FieldMatrix<double,1,1>>;
+  using Vec = BlockVector<FieldVector<double,1>>;
+
+  // explicit template instantiation of FastAMG preconditioner
+  template class Amg::FastAMG<MatrixAdapter<Mat,Vec,Vec>, Vec, Amg::SequentialInformation>;
+
+} // end namespace Dune
+
+
 template<class M, class V>
 void randomize(const M& mat, V& b)
 {
@@ -39,11 +52,11 @@ void testAMG(int N, int coarsenTarget, int ml)
   typedef Dune::FieldVector<double,BS> VectorBlock;
   typedef Dune::BlockVector<VectorBlock> Vector;
   typedef Dune::MatrixAdapter<BCRSMat,Vector,Vector> Operator;
-  typedef Dune::CollectiveCommunication<void*> Comm;
+  typedef Dune::Communication<void*> Comm;
   int n;
 
   Comm c;
-  BCRSMat mat = setupAnisotropic2d<BCRSMat>(N, indices, c, &n, 1);
+  BCRSMat mat = setupAnisotropic2d<MatrixBlock>(N, indices, c, &n, 1);
 
   Vector b(mat.N()), x(mat.M());
 
@@ -81,6 +94,9 @@ void testAMG(int N, int coarsenTarget, int ml)
 
   AMG amg(fop, criterion, parms);
 
+  // check if recalculation of matrix hierarchy works
+  amg.recalculateHierarchy();
+
   double buildtime = watch.elapsed();
 
   std::cout<<"Building hierarchy took "<<buildtime<<" seconds"<<std::endl;
@@ -130,7 +146,8 @@ try
 }
 catch (std::exception &e)
 {
-  throw;
+  std::cout << "ERROR: " << e.what() << std::endl;
+  return 1;
 }
 catch (...)
 {
