@@ -1,10 +1,13 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include <config.h>
 
 #include <iostream>
+#include <tuple>
 #include <dune/common/enumset.hh>
-#include <dune/common/tuples.hh>
+#include <dune/common/propertymap.hh>
 #include <dune/common/parallel/communicator.hh>
 #include <dune/istl/paamg/galerkin.hh>
 #include <dune/istl/paamg/dependency.hh>
@@ -12,13 +15,10 @@
 #include <dune/istl/paamg/pinfo.hh>
 #include <dune/istl/io.hh>
 #include <dune/istl/bcrsmatrix.hh>
-#include <dune/common/fmatrix.hh>
 #include <dune/istl/paamg/indicescoarsener.hh>
 #include <dune/istl/paamg/galerkin.hh>
 #include <dune/istl/owneroverlapcopy.hh>
-#include <dune/common/propertymap.hh>
 #include "anisotropic.hh"
-//#include<dune/istl/paamg/aggregates.hh>
 
 template<int BS>
 void testCoarsenIndices(int N)
@@ -40,10 +40,10 @@ void testCoarsenIndices(int N)
   ParallelIndexSet& indices = pinfo.indexSet();
   RemoteIndices& remoteIndices = pinfo.remoteIndices();
 
-  typedef Dune::CollectiveCommunication<MPI_Comm> Comm;
+  typedef Dune::Communication<MPI_Comm> Comm;
   Comm cc(MPI_COMM_WORLD);
 
-  BCRSMat mat = setupAnisotropic2d<BCRSMat>(N, indices, cc, &n);
+  BCRSMat mat = setupAnisotropic2d<Block>(N, indices, cc, &n);
 
   pinfo.remoteIndices().template rebuild<false>();
 
@@ -74,7 +74,7 @@ void testCoarsenIndices(int N)
 
   int noAggregates, isoAggregates, oneAggregates, skipped;
 
-  Dune::tie(noAggregates, isoAggregates, oneAggregates,skipped) = aggregatesMap.buildAggregates(mat, pg, Criterion(), false);
+  std::tie(noAggregates, isoAggregates, oneAggregates,skipped) = aggregatesMap.buildAggregates(mat, pg, Criterion(), false);
 
   Dune::Amg::printAggregates2d(aggregatesMap, n, N, std::cout);
 
