@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 // start with including some headers
@@ -349,16 +351,12 @@ void setupAnisotropic(M& A, double eps)
 template<class N, class G>
 void printWeightedGraph(G& graph, std::ostream& os, const N& norm=N())
 {
-  using Dune::remove_const;
-  using Dune::is_same;
-  using Dune::conditional;
-
-  typedef typename remove_const<G>::type Mutable;
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::remove_const<G>::type Mutable;
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::VertexIterator,
       typename G::ConstVertexIterator>::type VertexIterator;
 
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::EdgeIterator,
       typename G::ConstEdgeIterator>::type EdgeIterator;
   for(VertexIterator vertex = graph.begin(); vertex!=graph.end(); ++vertex) {
@@ -375,16 +373,12 @@ void printWeightedGraph(G& graph, std::ostream& os, const N& norm=N())
 template<class G>
 void printPropertiesGraph(G& graph, std::ostream& os)
 {
-  using Dune::remove_const;
-  using Dune::is_same;
-  using Dune::conditional;
-
-  typedef typename remove_const<G>::type Mutable;
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::remove_const<G>::type Mutable;
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::VertexIterator,
       typename G::ConstVertexIterator>::type VertexIterator;
 
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::EdgeIterator,
       typename G::ConstEdgeIterator>::type EdgeIterator;
   for(VertexIterator vertex = graph.begin(); vertex!=graph.end(); ++vertex) {
@@ -401,16 +395,12 @@ void printPropertiesGraph(G& graph, std::ostream& os)
 template<class G>
 void printGraph(G& graph, std::ostream& os)
 {
-  using Dune::remove_const;
-  using Dune::is_same;
-  using Dune::conditional;
-
-  typedef typename remove_const<G>::type Mutable;
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::remove_const<G>::type Mutable;
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::VertexIterator,
       typename G::ConstVertexIterator>::type VertexIterator;
 
-  typedef typename conditional<is_same<G,Mutable>::value,
+  typedef typename std::conditional<std::is_same<G,Mutable>::value,
       typename G::EdgeIterator,
       typename G::ConstEdgeIterator>::type EdgeIterator;
   for(VertexIterator vertex = graph.begin(); vertex!=graph.end(); ++vertex) {
@@ -562,7 +552,8 @@ int main (int argc , char ** argv)
   }
   catch(std::exception& e)
   {
-    throw;
+    std::cout << "ERROR: " << e.what() << std::endl;
+    return 1;
   }
   catch (...)
   {
