@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
@@ -18,7 +20,7 @@
 #include "anisotropic.hh"
 #include <dune/common/timer.hh>
 #include <dune/common/parallel/indexset.hh>
-#include <dune/common/parallel/collectivecommunication.hh>
+#include <dune/common/parallel/communication.hh>
 #include <dune/istl/paamg/amg.hh>
 #include <dune/istl/paamg/fastamg.hh>
 #include <dune/istl/paamg/pinfo.hh>
@@ -66,7 +68,7 @@ typedef Dune::BCRSMatrix<MatrixBlock> BCRSMat;
 typedef Dune::FieldVector<XREAL,1> VectorBlock;
 typedef Dune::BlockVector<VectorBlock> Vector;
 typedef Dune::MatrixAdapter<BCRSMat,Vector,Vector> Operator;
-typedef Dune::CollectiveCommunication<void*> Comm;
+typedef Dune::Communication<void*> Comm;
 typedef Dune::SeqSSOR<BCRSMat,Vector,Vector> Smoother;
 typedef Dune::Amg::SmootherTraits<Smoother>::Arguments SmootherArgs;
 
@@ -96,15 +98,6 @@ void *solve(void* arg)
   pthread_exit(NULL);
 }
 
-void *solve1(void* arg)
-{
-  thread_arg *amgarg=(thread_arg*) arg;
-  *amgarg->x=0;
-  (*amgarg->amg).apply(*amgarg->x,*amgarg->b);
-  (*amgarg->amg).post(*amgarg->x);
-  return 0;
-}
-
 void *solve2(void* arg)
 {
   thread_arg *amgarg=(thread_arg*) arg;
@@ -127,7 +120,7 @@ void testAMG(int N, int coarsenTarget, int ml)
   int n;
 
   Comm c;
-  BCRSMat mat = setupAnisotropic2d<BCRSMat>(N, indices, c, &n, 1);
+  BCRSMat mat = setupAnisotropic2d<MatrixBlock>(N, indices, c, &n, 1);
 
   Vector b(mat.N()), x(mat.M());
 
@@ -199,21 +192,6 @@ void testAMG(int N, int coarsenTarget, int ml)
   }
   void* retval;
 
-  for(int i=0; i < NUM_THREADS; ++i)
-    pthread_join(threads[i], &retval);
-
-  amgs.clear();
-  args.clear();
-  amg.pre(x, b);
-  amgs.resize(NUM_THREADS, amg);
-  for(int i=0; i < NUM_THREADS; ++i)
-  {
-    args[i].amg=&amgs[i];
-    args[i].b=&bs[i];
-    args[i].x=&xs[i];
-    args[i].fop=&fop;
-    pthread_create(&threads[i], NULL, solve1, (void*) &args[i]);
-  }
   for(int i=0; i < NUM_THREADS; ++i)
     pthread_join(threads[i], &retval);
 
@@ -259,7 +237,8 @@ try
 }
 catch (std::exception &e)
 {
-  throw;
+  std::cout << "ERROR: " << e.what() << std::endl;
+  return 1;
 }
 catch (...)
 {
