@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 /**
@@ -7,10 +9,8 @@
  *        \f$A*x = b\f$ with \f$A\f$ being a \f$N^2 \times N^2\f$
  *        Laplacian and \f$b\f$ a complex valued rhs.
  */
+#include <config.h>
 
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include <complex>
 
 #include <dune/istl/bvector.hh>
@@ -173,7 +173,7 @@ int main(int argc, char** argv)
 
   DummyPreconditioner dummyPrec(1.);
 
-  const FIELD_TYPE relaxFactor(1.);
+  const typename Dune::FieldTraits<FIELD_TYPE>::real_type relaxFactor(1.);
   JacobiPreconditioner jacobiPrec1(mat,1,relaxFactor);
   JacobiPreconditioner jacobiPrec2(mat,maxIter,relaxFactor);
 
@@ -188,6 +188,8 @@ int main(int argc, char** argv)
 #if HAVE_SUPERLU
   Dune::SuperLU<BCRSMat> solverSuperLU(mat, true);
   std::cout << "SuperLU converged:  "<< solverTest(solverSuperLU) << std::endl <<  std::endl;
+#else
+  std::cout << "SuperLU skipped because not found." << std::endl <<  std::endl;
 #endif
 
   typedef  Dune::GradientSolver<Vector> GradientSolver;
