@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
@@ -20,6 +22,15 @@ int main(int argc, char** argv)
 
   const int N=4;
 
+  // Test sparse matrix with scalar entries
+  Dune::BCRSMatrix<double> slaplace;
+  setupLaplacian(slaplace, N);
+
+  if(N*N*5-4*2-(N-2)*4!=countNonZeros(slaplace)) {
+    ++ret;
+    Dune::derr<<"Counting nonzeros of BCRSMatrix<double> failed!"<<std::endl;
+  }
+
   typedef Dune::BCRSMatrix<Dune::FieldMatrix<double,1,1> > BMatrix;
 
   BMatrix laplace;
