@@ -1,3 +1,5 @@
+// SPDX-FileCopyrightText: Copyright (C) DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LicenseRef-GPL-2.0-only-with-DUNE-exception
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
 #include "config.h"
@@ -17,8 +19,6 @@ using namespace Dune;
 template<class K, int n>
 void test_matrix()
 {
-  typedef typename ScaledIdentityMatrix<K,n>::size_type size_type;
-
   ScaledIdentityMatrix<K,n> A(1);
   FieldVector<K,n> f;
   FieldVector<K,n> v;
@@ -33,6 +33,9 @@ void test_matrix()
   // matrix vector product
   A.umv(v,f);
 
+  // matrix times scalar
+  [[maybe_unused]] auto r1 = A * 23.;
+  [[maybe_unused]] auto r2 = 42. * A;
 
   // test norms
   A.frobenius_norm();
@@ -48,7 +51,7 @@ void test_matrix()
   std::cout << f << std::endl;
 
   // Construction of FieldMatrix from ScaledIdentityMatrix
-  FieldMatrix<K,n,n> AFM DUNE_UNUSED = FieldMatrix<K,n,n>(A);
+  [[maybe_unused]] FieldMatrix<K,n,n> AFM = FieldMatrix<K,n,n>(A);
 }
 
 int main()
